# Netskope Integration for SaaS Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#introduction)
  * [Implementation Details](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#implementation-details)
  * [Discovery Capabilities](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#discovery-capabilities)
  * [Setting up Netskope Integration](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#setting-up-netskope-integration)
  * [Create New API Token in Netskope](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#create-new-api-token-in-netskope)
  * [Enter the Necessary Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery#enter-the-necessary-credentials-in-sap-leanix)


Set up an integration with Netskope to streamline the discovery of your SaaS applications.
